instrumenttools.InstrumentationSpecifier
========================================

.. abjad-lineage:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier

.. autoclass:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.instrument_count
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.instruments
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performer_count
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performer_name_string
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performers
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__eq__
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__format__
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__ne__
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.instrument_count
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.instruments
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performer_count
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performer_name_string
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.performers
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__format__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier.__repr__
   :noindex:
